@@ -2,8 +2,8 @@
 # -*- coding: utf-8 -*-
 # cython: language_level=3, always_allow_keywords=True
 
-## Copyright 2005-2019 by LivingLogic AG, Bayreuth/Germany
-## Copyright 2005-2019 by Walter Dörwald
+## Copyright 2005-2021 by LivingLogic AG, Bayreuth/Germany
+## Copyright 2005-2021 by Walter Dörwald
 ##
 ## All Rights Reserved
 ##
@@ -87,7 +87,7 @@ Example
 Compare the schemas ``user@db`` and ``user2@db2``, collapsing whitespace and
 using unified diff mode with 5 context lines:
 
-.. sourcecode:: bash
+.. sourcecode:: console
 
 	$ oradiff user/pwd@db user2/pwd2@db2 -bcollapse -mudiff -n5 -v >db.diff
 """
