@@ -2,15 +2,15 @@
 # -*- coding: utf-8 -*-
 # cython: language_level=3, always_allow_keywords=True
 
-## Copyright 2011-2019 by LivingLogic AG, Bayreuth/Germany
-## Copyright 2011-2019 by Walter Dörwald
+## Copyright 2011-2021 by LivingLogic AG, Bayreuth/Germany
+## Copyright 2011-2021 by Walter Dörwald
 ##
 ## All Rights Reserved
 ##
 ## See ll/xist/__init__.py for the license
 
 
-import sys, io, os, json, datetime, math, tempfile, shutil, subprocess
+import sys, os, json, datetime, math, tempfile, shutil, subprocess, re
 
 import pytest
 
@@ -24,6 +24,29 @@ home = os.environ["HOME"]
 # ``UL4ONBUFFER_PKG`` from https://github.com/LivingLogic/LivingLogic.Oracle.ul4
 # are installed
 
+re_test_name = re.compile("(?P<file>[a-z0-9_/.]+)::(?P<test>[a-zA-Z0-9_]+)(?:\\[(?P<param>[a-z0-9_]+)\\])? \\((?P<phase>[a-z]+)\\)")
+
+
+def make_func_name():
+	m = re_test_name.match(os.environ.get("PYTEST_CURRENT_TEST"))
+	test = m.group('test')
+	if test.startswith("test_oracle_"):
+		test = test[12:]
+	elif test.startswith("test_"):
+		test = test[5:]
+	funcname = f"test_ul4on_{test}"
+	param = m.group('param')
+	if param:
+		if param.startswith("oracle_"):
+			param = param[7:]
+		if param == "ul4on":
+			param = ""
+		elif param == "ul4onbuffer":
+			param = "buf"
+		if param:
+			funcname = f"{funcname}_{param}"
+	return funcname
+
 
 def oracle_ul4on(code):
 	"""
@@ -45,12 +68,13 @@ def oracle_ul4on(code):
 	"""
 	connectstring = os.environ.get("LL_ORASQL_TEST_CONNECT")
 	if connectstring:
+		funcname = make_func_name()
+
 		from ll import orasql
 		db = orasql.connect(connectstring, readlobs=True)
 		cursor = db.cursor()
-		print(code)
-		cursor.execute(f"""
-			create or replace function ul4ontest
+		code = f"""
+			create or replace function {funcname}
 			return clob
 			as
 				c_out clob;
@@ -58,9 +82,11 @@ def oracle_ul4on(code):
 				{code}
 				return c_out;
 			end;
-		""")
-		cursor.execute("select ul4ontest from dual")
-		dump = cursor.fetchone().ul4ontest
+		"""
+		print(code)
+		cursor.execute(code)
+		cursor.execute(f"select {funcname} as ul4ondump from dual")
+		dump = cursor.fetchone().ul4ondump
 		return ul4on.loads(dump)
 	else:
 		return None
@@ -93,11 +119,13 @@ def oracle_ul4onbuffer(code):
 	"""
 	connectstring = os.environ.get("LL_ORASQL_TEST_CONNECT")
 	if connectstring:
+		funcname = make_func_name()
+
 		from ll import orasql
 		db = orasql.connect(connectstring, readlobs=True)
 		cursor = db.cursor()
-		cursor.execute(f"""
-			create or replace function ul4ontest
+		code = f"""
+			create or replace function {funcname}
 			return clob
 			as
 				c_out clob;
@@ -107,9 +135,11 @@ def oracle_ul4onbuffer(code):
 				ul4onbuffer_pkg.flush(c_out);
 				return c_out;
 			end;
-		""")
-		cursor.execute("select ul4ontest from dual")
-		dump = cursor.fetchone().ul4ontest
+		"""
+		print(code)
+		cursor.execute(code)
+		cursor.execute(f"select {funcname} as ul4ondump from dual")
+		dump = cursor.fetchone().ul4ondump
 		return ul4on.loads(dump)
 	else:
 		return None
@@ -257,7 +287,7 @@ def java_runsource(source):
 		public static void main(String[] args) throws java.io.IOException, java.io.UnsupportedEncodingException, org.antlr.runtime.RecognitionException, ClassNotFoundException
 		{{
 			// Force the JVM to register the UL4 classes for UL4ON
-			Class.forName("com.livinglogic.ul4.InterpretedTemplate");
+			Class.forName("com.livinglogic.ul4.Template");
 			{source}
 		}}
 	}}
@@ -351,7 +381,12 @@ def test_bool(t):
 def test_int(t):
 	assert 42 == t(42)
 	assert -42 == t(-42)
-
+	assert 2147483647 == t(2147483647)
+	assert -2147483648 == t(-2147483648)
+	if t not in (transport_js_v8, transport_js_v8_pretty, transport_js_node, transport_js_node_pretty):
+		assert 9223372036854775807 == t(9223372036854775807)
+		assert -9223372036854775808 == t(-9223372036854775808)
+		assert 10**30 == t(10**30)
 
 def test_float(t):
 	assert -42.5 == t(-42.5)
@@ -480,13 +515,11 @@ def test_nested(t):
 
 
 def test_template_from_source():
-	t = ul4on.loads("o s'de.livinglogic.ul4.template' n s'test' s'<?print x + y?>' s'x, y=23' s'keep' n n )")
+	t = ul4on.loads("o s'de.livinglogic.ul4.template' n s'test' s'<?print x + y?>' s'x, y=23' s'keep' )")
 
 	assert t.name == "test"
 	assert t.source == "<?ul4 test(x, y=23)?><?print x + y?>"
 	assert t.whitespace == "keep"
-	assert t.startdelim == "<?"
-	assert t.enddelim == "?>"
 	assert t.renders(17) == "40"
 
 
@@ -569,6 +602,143 @@ def test_custom_class(t):
 		assert isinstance(p, PointContent)
 
 
+def test_chunked_encoder():
+	encoder = ul4on.Encoder()
+	s1 = "gurk"
+	s2 = "hurz"
+	assert "S'gurk'" == encoder.dumps(s1)
+	assert "S'hurz'" == encoder.dumps(s2)
+	assert "^0" == encoder.dumps(s1)
+	assert "^1" == encoder.dumps(s2)
+
+
+def test_chunked_decoder():
+	decoder = ul4on.Decoder()
+	assert "gurk" == decoder.loads("S'gurk'")
+	assert "hurz" == decoder.loads("S'hurz'")
+	assert "gurk" == decoder.loads("^0")
+	assert "hurz" == decoder.loads("^1")
+
+
+def test_incremental_without_id():
+	class Point:
+		ul4onname = "de.livinglogic.ul4.test.point"
+
+		def __init__(self, id=None, x=None, y=None):
+			self.ul4onid = id
+			self.x = x
+			self.y = y
+
+		def ul4ondump(self, encoder):
+			encoder.dump(self.x)
+			encoder.dump(self.y)
+
+		def ul4onload(self, decoder):
+			self.x = decoder.load()
+			self.y = decoder.load()
+
+	registry = {Point.ul4onname: Point}
+
+	p1 = Point(None, 17, 23)
+
+	encoder = ul4on.Encoder()
+	# Since ``ul4onid`` is ``None`` ``p1`` will not be treated as a persistent object
+	dump = encoder.dumps(p1)
+
+	decoder = ul4on.Decoder(registry)
+
+	dump = dump.replace(" i23 ", " i24 ")
+	p2 = decoder.loads(dump)
+
+	assert p1 is not p2
+
+	assert p1.ul4onid is None
+	assert p1.x == 17
+	assert p1.y == 23
+
+	assert p2.ul4onid is None
+	assert p2.x == 17
+	assert p2.y == 24
+
+	# Reset backreferences
+	decoder.reset()
+
+	# Decode a modified dump a second time
+	dump = dump.replace(" i24 ", " i25 ")
+	p3 = decoder.loads(dump)
+
+	# Since ``p1`` wasn't treated as persistent, the decoder didn't remember ``p2``
+	# So ``p3`` is different
+	assert p2 is not p3
+
+	assert p2.ul4onid is None
+	assert p2.x == 17
+	assert p2.y == 24
+
+	assert p3.ul4onid is None
+	assert p3.x == 17
+	assert p3.y == 25
+
+
+def test_incremental_with_id():
+	class Point:
+		ul4onname = "de.livinglogic.ul4.test.point"
+
+		def __init__(self, id, x=None, y=None):
+			self.ul4onid = id
+			self.x = x
+			self.y = y
+
+		def ul4ondump(self, encoder):
+			encoder.dump(self.x)
+			encoder.dump(self.y)
+
+		def ul4onload(self, decoder):
+			self.x = decoder.load()
+			self.y = decoder.load()
+
+	registry = {Point.ul4onname: Point}
+
+	p1 = Point("foo", 17, 23)
+
+	encoder = ul4on.Encoder()
+	dump = encoder.dumps(p1)
+
+	decoder = ul4on.Decoder(registry)
+
+	dump = dump.replace(" i23 ", " i24 ")
+	p2 = decoder.loads(dump)
+
+	# The decoder hasn't seen this object yet,
+	# so the deserialized objects is not the original one,
+	# but it has the correct attributes.
+	# The attributes of the original object are unchanged.
+	assert p1 is not p2
+
+	assert p1.ul4onid == "foo"
+	assert p1.x == 17
+	assert p1.y == 23
+
+	assert p2.ul4onid == "foo"
+	assert p2.x == 17
+	assert p2.y == 24
+
+	# Reset backreferences
+	decoder.reset()
+
+	# Decode a modified dump a second time
+	dump = dump.replace(" i24 ", " i25 ")
+	p3 = decoder.loads(dump)
+
+	# Now the :meth:`loads` call has updated the object ``p2`` that already exists
+	# The attributes have been updated according to the info in the dump.
+	assert p2 is p3
+
+	assert p3.ul4onid == "foo"
+	assert p3.x == 17
+	assert p3.y == 25
+
+
 @pytest.mark.db
 def test_oracle_none(oracle):
 	if oracle:
